@@ -13,7 +13,7 @@ import seaborn as sns
 sns.set(rc={'figure.figsize': (10, 8)}, font_scale=1.3)
 
 
-class Psmpy:
+class PsmPy:
     """
     Matcher Class -- Match data for an observational study.
     Parameters
